@@ -19,7 +19,7 @@
 import random
 import weakref
 from collections.abc import KeysView
-from typing import Optional, Dict, Iterable, List, Tuple
+from typing import Optional, Dict, Iterable, List, Tuple, NamedTuple, Union, Any
 
 import binascii
 import itertools
@@ -32,13 +32,12 @@ from nucypher.utilities.logging import Logger
 from .nicknames import Nickname
 
 
-class ArchivedFleetState:
+class ArchivedFleetState(NamedTuple):
 
-    def __init__(self, checksum: str, nickname: Nickname, timestamp: maya.MayaDT, population: int):
-        self.checksum = checksum
-        self.nickname = nickname
-        self.timestamp = timestamp
-        self.population = population
+    checksum: ChecksumAddress
+    nickname: Nickname
+    timestamp: maya.MayaDT
+    population: int
 
     def to_json(self):
         return dict(checksum=self.checksum,
@@ -47,6 +46,15 @@ class ArchivedFleetState:
                     population=self.population)
 
 
+class StateDiff(NamedTuple):
+    this_node_updated: bool
+    nodes_updated: List[ChecksumAddress]
+    nodes_removed: List[ChecksumAddress]
+
+    def empty(self):
+        return not self.this_node_updated and not self.nodes_updated and not self.nodes_removed
+
+
 class FleetState:
     """
     Fleet state as perceived by a local Ursula.
@@ -93,24 +101,28 @@ class FleetState:
                                   timestamp=self.timestamp,
                                   population=self.population)
 
-    def _remote_nodes_updated(self,
-                              nodes_to_add: Iterable['Ursula'],
-                              nodes_to_remove: Iterable[ChecksumAddress]
-                              ) -> bool:
+    def _calculate_diff(self,
+                        this_node_updated: bool,
+                        nodes_to_add: Iterable['Ursula'],
+                        nodes_to_remove: Iterable[ChecksumAddress]
+                        ) -> StateDiff:
 
+        nodes_updated = []
         for node in nodes_to_add:
             if node.checksum_address in nodes_to_remove:
                 continue
-            if node.checksum_address not in self._nodes:
-                return True
-            if bytes(self._nodes[node.checksum_address]) != bytes(node):
-                return True
+            unknown = node.checksum_address not in self._nodes
+            if unknown or bytes(self._nodes[node.checksum_address]) != bytes(node):
+                nodes_updated.append(node.checksum_address)
 
+        nodes_removed = []
         for checksum_address in nodes_to_remove:
             if checksum_address in self._nodes:
-                return True
+                nodes_removed.append(checksum_address)
 
-        return False
+        return StateDiff(this_node_updated=this_node_updated,
+                         nodes_updated=nodes_updated,
+                         nodes_removed=nodes_removed)
 
     def with_updated_nodes(self,
                            nodes_to_add: Iterable['Ursula'],
@@ -121,25 +133,27 @@ class FleetState:
         if self._this_node_ref is not None and not skip_this_node:
             this_node = self._this_node_ref()
             this_node_metadata = bytes(this_node)
-            this_node_changed = self._this_node_metadata != this_node_metadata
+            this_node_updated = self._this_node_metadata != this_node_metadata
             this_node_list = [this_node]
         else:
             this_node_metadata = self._this_node_metadata
-            this_node_changed = False
+            this_node_updated = False
             this_node_list = []
 
-        remote_nodes_updated = self._remote_nodes_updated(nodes_to_add, nodes_to_remove)
+        diff = self._calculate_diff(this_node_updated, nodes_to_add, nodes_to_remove)
 
-        if this_node_changed or remote_nodes_updated:
+        if not diff.empty():
             # TODO: if nodes were kept in a Merkle tree,
             # we'd have to only recalculate log(N) checksums.
             # Is it worth it?
             nodes = dict(self._nodes)
-            for node in nodes_to_add:
-                nodes[node.checksum_address] = node
-            for checksum_address in nodes_to_remove:
-                if checksum_address in nodes:
-                    del nodes[checksum_address]
+            nodes_to_add_dict = {node.checksum_address: node for node in nodes_to_add}
+            for checksum_address in diff.nodes_updated:
+                new_node = nodes_to_add_dict[checksum_address]
+                new_node.mature()
+                nodes[checksum_address] = new_node
+            for checksum_address in diff.nodes_removed:
+                del nodes[checksum_address]
 
             all_nodes_sorted = sorted(itertools.chain(this_node_list, nodes.values()),
                                       key=lambda node: node.checksum_address)
@@ -149,10 +163,12 @@ class FleetState:
             nodes = self._nodes
             checksum = self.checksum
 
-        return FleetState(checksum=checksum,
-                          nodes=nodes,
-                          this_node_ref=self._this_node_ref,
-                          this_node_metadata=this_node_metadata)
+        new_state = FleetState(checksum=checksum,
+                               nodes=nodes,
+                               this_node_ref=self._this_node_ref,
+                               this_node_metadata=this_node_metadata)
+
+        return new_state, diff
 
     @property
     def population(self) -> int:
@@ -239,7 +255,8 @@ class FleetSensor:
 
         self._current_state = FleetState.new(this_node)
         self._archived_states = [self._current_state.archived()]
-        self.remote_states = {}
+        self._remote_states = {}
+        self._remote_last_seen = {}
 
         # temporary accumulator for new nodes to avoid updating the fleet state every time
         self._nodes_to_add = set()
@@ -311,13 +328,18 @@ class FleetSensor:
     def values(self):
         return self._current_state.values()
 
-    def latest_states(self, quantity: int) -> List[ArchivedFleetState]:
+    def latest_state(self) -> ArchivedFleetState:
+        # `_archived_states` is never empty, one state is created in the constructor
+        return self._archived_states[-1]
+
+    def previous_states(self, quantity: int) -> List[ArchivedFleetState]:
         """
-        Returns at most ``quantity`` latest archived states (including the current one),
+        Returns at most ``quantity`` latest archived states (*not* including the current one),
         in chronological order.
         """
-        latest = self._archived_states[-min(len(self._archived_states), quantity):]
-        return latest
+        # `_archived_states` is never empty, one state is created in the constructor
+        previous_states_num = min(len(self._archived_states) - 1, quantity)
+        return self._archived_states[-previous_states_num-1:-1]
 
     def addresses(self):
         return self._current_state.addresses()
@@ -329,10 +351,10 @@ class FleetSensor:
     def unpack_snapshot(data):
         return FleetState.unpack_snapshot(data)
 
-    def record_fleet_state(self, skip_this_node: bool = False):
-        new_state = self._current_state.with_updated_nodes(nodes_to_add=self._nodes_to_add,
-                                                           nodes_to_remove=self._nodes_to_remove,
-                                                           skip_this_node=skip_this_node)
+    def record_fleet_state(self, skip_this_node: bool = False) -> StateDiff:
+        new_state, diff = self._current_state.with_updated_nodes(nodes_to_add=self._nodes_to_add,
+                                                                 nodes_to_remove=self._nodes_to_remove,
+                                                                 skip_this_node=skip_this_node)
 
         self._nodes_to_add = set()
         self._nodes_to_remove = set()
@@ -343,8 +365,11 @@ class FleetSensor:
         # 1. (current) add a state to the archive every time it changes
         # 2. (possible) keep a dictionary of known states
         #    and bump the timestamp of a previously encountered one
-        if new_state.checksum != self._archived_states[-1].checksum:
-            self._archived_states.append(new_state.archived())
+        if not diff.empty():
+            archived_state = new_state.archived()
+            self._archived_states.append(archived_state)
+
+        return diff
 
     def shuffled(self):
         return self._current_state.shuffled()
@@ -358,8 +383,65 @@ class FleetSensor:
                                   state_checksum: str,
                                   timestamp: maya.MayaDT,
                                   population: int):
+
+        if checksum_address not in self._current_state:
+            raise KeyError(f"A node {checksum_address} is not present in the current fleet state")
+
         nickname = Nickname.from_seed(state_checksum, length=1)
-        self.remote_states[checksum_address] = ArchivedFleetState(checksum=state_checksum,
-                                                                  nickname=nickname,
-                                                                  timestamp=timestamp,
-                                                                  population=population)
+        state = ArchivedFleetState(checksum=state_checksum,
+                                   nickname=nickname,
+                                   timestamp=timestamp,
+                                   population=population)
+
+        self._remote_last_seen[checksum_address] = maya.now()
+        self._remote_states[checksum_address] = state
+
+    def status_info(self, checksum_address_or_node: Union[ChecksumAddress, 'Ursula']) -> 'RemoteUrsulaStatus':
+
+        if isinstance(checksum_address_or_node, str):
+            node = self[checksum_address_or_node]
+        else:
+            node = checksum_address_or_node
+
+        recorded_fleet_state = self._remote_states.get(node.checksum_address, None)
+        last_learned_from = self._remote_last_seen.get(node.checksum_address, None)
+        worker_address = node.worker_address if node.verified_node else None
+
+        return RemoteUrsulaStatus(verified=node.verified_node,
+                                  nickname=node.nickname,
+                                  staker_address=node.checksum_address,
+                                  worker_address=worker_address,
+                                  rest_url=node.rest_url(),
+                                  timestamp=node.timestamp,
+                                  last_learned_from=last_learned_from,
+                                  recorded_fleet_state=recorded_fleet_state,
+                                  )
+
+
+class RemoteUrsulaStatus(NamedTuple):
+    verified: bool
+    nickname: Nickname
+    staker_address: ChecksumAddress
+    worker_address: Optional[ChecksumAddress]
+    rest_url: str
+    timestamp: maya.MayaDT
+    recorded_fleet_state: Optional[ArchivedFleetState]
+    last_learned_from: Optional[maya.MayaDT]
+
+    def to_json(self) -> Dict[str, Any]:
+        if self.recorded_fleet_state is None:
+            recorded_fleet_state_json = None
+        else:
+            recorded_fleet_state_json = recorded_fleet_state.to_json()
+        if self.last_learned_from is None:
+            last_learned_from_json = None
+        else:
+            last_learned_from_json = last_learned_from.iso8601()
+        return dict(verified=self.verified,
+                    nickname=self.nickname.to_json(),
+                    staker_address=self.staker_address,
+                    worker_address=self.worker_address,
+                    rest_url=self.rest_url,
+                    timestamp=self.timestamp.iso8601(),
+                    recorded_fleet_state=recorded_fleet_state_json,
+                    last_learned_from=last_learned_from_json)
