@@ -14,16 +14,18 @@
  You should have received a copy of the GNU Affero General Public License
  along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 """
-from tabulate import tabulate
-from typing import Type, Union, Dict
+
 
 import click
 from constant_sorrow.constants import UNKNOWN_DEVELOPMENT_CHAIN_ID
+from datetime import datetime
+from tabulate import tabulate
+from typing import Type, Union, Dict
+from web3.main import Web3
 
 from nucypher.blockchain.eth.deployers import BaseContractDeployer
-from nucypher.blockchain.eth.registry import LocalContractRegistry, InMemoryContractRegistry
-from nucypher.cli.literature import CONFIRM_VERSIONED_UPGRADE
 from nucypher.blockchain.eth.interfaces import BlockchainDeployerInterface, VersionedContract, BlockchainInterface
+from nucypher.blockchain.eth.registry import LocalContractRegistry
 from nucypher.blockchain.eth.token import NU
 from nucypher.characters.control.emitters import StdoutEmitter
 from nucypher.cli.literature import (
@@ -33,15 +35,14 @@ from nucypher.cli.literature import (
     CONFIRM_ENABLE_WINDING_DOWN,
     CONFIRM_LARGE_STAKE_DURATION,
     CONFIRM_LARGE_STAKE_VALUE,
-    CONFIRM_RESTAKING_LOCK,
     CONFIRM_STAGED_STAKE,
     RESTAKING_AGREEMENT,
-    RESTAKING_LOCK_AGREEMENT,
     WINDING_DOWN_AGREEMENT,
     SNAPSHOTS_DISABLING_AGREEMENT,
     CONFIRM_DISABLE_SNAPSHOTS
 )
-from nucypher.config.node import CharacterConfiguration
+from nucypher.cli.literature import CONFIRM_VERSIONED_UPGRADE
+from nucypher.config.base import CharacterConfiguration
 
 
 def confirm_deployment(emitter: StdoutEmitter, deployer_interface: BlockchainDeployerInterface) -> bool:
@@ -61,13 +62,6 @@ def confirm_deployment(emitter: StdoutEmitter, deployer_interface: BlockchainDep
     return True
 
 
-def confirm_enable_restaking_lock(emitter: StdoutEmitter, staking_address: str, release_period: int) -> bool:
-    """Interactively confirm enabling of the staking lock with user agreements."""
-    emitter.message(RESTAKING_LOCK_AGREEMENT.format(staking_address=staking_address, release_period=release_period))
-    click.confirm(CONFIRM_RESTAKING_LOCK.format(staking_address=staking_address, release_period=release_period), abort=True)
-    return True
-
-
 def confirm_enable_restaking(emitter: StdoutEmitter, staking_address: str) -> bool:
     """Interactively confirm enabling of the restaking with user agreements."""
     emitter.message(RESTAKING_AGREEMENT.format(staking_address=staking_address))
@@ -147,9 +141,41 @@ def verify_upgrade_details(blockchain: Union[BlockchainDeployerInterface, Blockc
                                                    new_version=new_version), abort=True)
 
 
-def confirm_staged_grant(emitter, grant_request: Dict) -> None:
-    # TODO: Expand and detail
-    emitter.echo("Successfully staged grant.  Please review the details:\n", color='green')
-    table = ([field, value] for field, value in grant_request.items())
+def confirm_staged_grant(emitter, grant_request: Dict, federated: bool) -> None:
+
+    pretty_request = grant_request.copy()  # WARNING: Do not mutate
+
+    if federated:  # Boring
+        table = [[field.capitalize(), value] for field, value in pretty_request.items()]
+        emitter.echo(tabulate(table, tablefmt="simple"))
+        return
+
+    period_rate = Web3.fromWei(pretty_request['n'] * pretty_request['rate'], 'gwei')
+    pretty_request['rate'] = f"{pretty_request['rate']} wei/period * {pretty_request['n']} nodes"
+
+    expiration = pretty_request['expiration']
+    periods = (expiration - datetime.now()).days
+    pretty_request['expiration'] = f"{pretty_request['expiration']} ({periods} periods)"
+
+    # M of N
+    pretty_request['Threshold Shares'] = f"{pretty_request['m']} of {pretty_request['n']}"
+    del pretty_request['m']
+    del pretty_request['n']
+
+    def prettify_field(field):
+        field_words = [word.capitalize() for word in field.split('_')]
+        field = ' '.join(field_words)
+        return field
+
+    table = [[prettify_field(field), value] for field, value in pretty_request.items()]
+    table.append(['Period Rate', f'{period_rate} gwei'])
+    table.append(['Policy Value', f'{period_rate * periods} gwei'])
+
+    # TODO: Use period calculation utilities instead of days
+    # periods = calculate_period_duration(future_time=maya.MayaDT(pretty_request['expiration']),
+    #                                     seconds_per_period=StandardTokenEconomics().seconds_per_period)
+
+
+    emitter.echo("\nSuccessfully staged grant, Please review the details:\n", color='green')
     emitter.echo(tabulate(table, tablefmt="simple"))
     click.confirm('\nGrant access and sign transaction?', abort=True)
