@@ -112,6 +112,7 @@ SELECT_STAKE = "Select Stake"
 
 NO_STAKES_FOUND = "No stakes found."
 
+
 POST_STAKING_ADVICE = """
 View your stakes by running 'nucypher stake list'
 or set your Ursula worker node address by running 'nucypher stake bond-worker'.
@@ -119,12 +120,28 @@ or set your Ursula worker node address by running 'nucypher stake bond-worker'.
 See https://docs.nucypher.com/en/latest/staking/running_a_worker.html
 """
 
-
 #
 # Events
 #
+
 CONFIRM_OVERWRITE_EVENTS_CSV_FILE = "Overwrite existing CSV events file - {csv_file}?"
 
+#
+# Remove Inactive
+#
+
+
+FETCHING_INACTIVE_STAKES = 'Fetching inactive stakes'
+
+NO_INACTIVE_STAKES = "No inactive stakes found\n"
+
+CONFIRM_REMOVE_ALL_INACTIVE_SUBSTAKES = """
+This action will perform a series of transactions to remove all unused sub-stakes
+(Indices {stakes}).  It is recommended that you verify each staker transaction was successful (https://etherscan.io/address/{staker_address}).
+
+Confirm removal of {quantity} unused sub-stakes?"""
+
+
 #
 # Minting
 #
