@@ -16,14 +16,17 @@ along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 import click
+from cryptography.exceptions import InternalError
 from decimal import Decimal, DecimalException
 from eth_utils import to_checksum_address
 from ipaddress import ip_address
+from umbral.keys import UmbralPublicKey
 
 from nucypher.blockchain.economics import StandardTokenEconomics
-from nucypher.blockchain.eth.token import NU
 from nucypher.blockchain.eth.interfaces import BlockchainInterface
 from nucypher.blockchain.eth.networks import NetworksInventory
+from nucypher.blockchain.eth.token import NU
+from nucypher.utilities.networking import validate_worker_ip, InvalidWorkerIP
 
 
 class ChecksumAddress(click.ParamType):
@@ -44,12 +47,24 @@ class IPv4Address(click.ParamType):
     def convert(self, value, param, ctx):
         try:
             _address = ip_address(value)
-        except ValueError as e:
+        except ValueError:
             self.fail("Invalid IP Address")
         else:
             return value
 
 
+class WorkerIPAddress(IPv4Address):
+    name = 'worker_ip'
+
+    def convert(self, value, param, ctx):
+        _ip = super().convert(value, param, ctx)
+        try:
+            validate_worker_ip(worker_ip=_ip)
+        except InvalidWorkerIP as e:
+            self.fail(str(e))
+        return value
+
+
 class DecimalType(click.ParamType):
     name = 'decimal'
 
@@ -103,6 +118,21 @@ class NuCypherNetworkName(click.ParamType):
             return value
 
 
+class UmbralPublicKeyHex(click.ParamType):
+    name = 'nucypher_umbral_public_key'
+
+    def __init__(self, validate: bool = True):
+        self.validate = bool(validate)
+
+    def convert(self, value, param, ctx):
+        if self.validate:
+            try:
+                _key = UmbralPublicKey.from_hex(value)
+            except (InternalError, ValueError):
+                self.fail(f"'{value}' is not a valid nucypher public key.")
+        return value
+
+
 # Ethereum
 EIP55_CHECKSUM_ADDRESS = ChecksumAddress()
 WEI = click.IntRange(min=1, clamp=False)  # TODO: Better validation for ether and wei values?
@@ -119,5 +149,7 @@ EXISTING_READABLE_FILE = click.Path(exists=True, dir_okay=False, file_okay=True,
 # Network
 NETWORK_PORT = click.IntRange(min=0, max=65535, clamp=False)
 IPV4_ADDRESS = IPv4Address()
+WORKER_IP = WorkerIPAddress()
 
 GAS_STRATEGY_CHOICES = click.Choice(list(BlockchainInterface.GAS_STRATEGIES.keys()))
+UMBRAL_PUBLIC_KEY_HEX = UmbralPublicKeyHex()
